==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/component/impl/InterfaceReferenceInDelegationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.DelegationSet;
import io.ciera.tool.sql.ooaofooa.component.InterfaceReferenceInDelegation;
import io.ciera.tool.sql.ooaofooa.component.InterfaceReferenceInDelegationSet;
import io.ciera.tool.sql.ooaofooa.component.InterfaceReferenceSet;
import io.ciera.tool.sql.ooaofooa.component.impl.DelegationSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.InterfaceReferenceSetImpl;

import java.util.Arrays;
import java.util.List;


public class InterfaceReferenceInDelegationSetImpl extends InstanceSet<InterfaceReferenceInDelegationSet,InterfaceReferenceInDelegation> implements InterfaceReferenceInDelegationSet {

    // attributes
    @Override
    public void setDelegation_Id( UniqueId ref_Delegation_Id ) throws XtumlException {
        for ( InterfaceReferenceInDelegation interfacereferenceindelegation : this ) interfacereferenceindelegation.setDelegation_Id( ref_Delegation_Id );
    }
    @Override
    public void setReference_Id( UniqueId ref_Reference_Id ) throws XtumlException {
        for ( InterfaceReferenceInDelegation interfacereferenceindelegation : this ) interfacereferenceindelegation.setReference_Id( ref_Reference_Id );
    }


    // selections
    @Override
    public InterfaceReferenceSet R4013_handles_delegation_for_InterfaceReference() throws XtumlException {
        InterfaceReferenceSet interfacereferenceset = new InterfaceReferenceSetImpl();
        for ( InterfaceReferenceInDelegation interfacereferenceindelegation : this ) interfacereferenceset.add( interfacereferenceindelegation.R4013_handles_delegation_for_InterfaceReference() );
        return interfacereferenceset;
    }
    @Override
    public DelegationSet R4013_may_delegate_through_Delegation() throws XtumlException {
        DelegationSet delegationset = new DelegationSetImpl();
        for ( InterfaceReferenceInDelegation interfacereferenceindelegation : this ) delegationset.add( interfacereferenceindelegation.R4013_may_delegate_through_Delegation() );
        return delegationset;
    }


    @Override
    public InterfaceReferenceInDelegation nullElement() {
        return InterfaceReferenceInDelegationImpl.EMPTY_INTERFACEREFERENCEINDELEGATION;
    }

    @Override
    public InterfaceReferenceInDelegationSet emptySet() {
      return new InterfaceReferenceInDelegationSetImpl();
    }

    @Override
    public InterfaceReferenceInDelegationSet value() {
        return this;
    }

    @Override
    public List<InterfaceReferenceInDelegation> elements() {
        return Arrays.asList(toArray(new InterfaceReferenceInDelegation[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/component/impl/InterfaceReferenceInDelegationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.DelegationSet;
import io.ciera.tool.sql.ooaofooa.component.InterfaceReferenceInDelegation;
import io.ciera.tool.sql.ooaofooa.component.InterfaceReferenceInDelegationSet;
import io.ciera.tool.sql.ooaofooa.component.InterfaceReferenceSet;
import io.ciera.tool.sql.ooaofooa.component.impl.DelegationSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.InterfaceReferenceSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class InterfaceReferenceInDelegationSetImpl extends InstanceSet<InterfaceReferenceInDelegationSet,InterfaceReferenceInDelegation> implements InterfaceReferenceInDelegationSet {

    public InterfaceReferenceInDelegationSetImpl() {
    }

    public InterfaceReferenceInDelegationSetImpl(Comparator<? super InterfaceReferenceInDelegation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDelegation_Id( UniqueId ref_Delegation_Id ) throws XtumlException {
        for ( InterfaceReferenceInDelegation interfacereferenceindelegation : this ) interfacereferenceindelegation.setDelegation_Id( ref_Delegation_Id );
    }
    @Override
    public void setReference_Id( UniqueId ref_Reference_Id ) throws XtumlException {
        for ( InterfaceReferenceInDelegation interfacereferenceindelegation : this ) interfacereferenceindelegation.setReference_Id( ref_Reference_Id );
    }


    // selections
    @Override
    public InterfaceReferenceSet R4013_handles_delegation_for_InterfaceReference() throws XtumlException {
        InterfaceReferenceSet interfacereferenceset = new InterfaceReferenceSetImpl();
        for ( InterfaceReferenceInDelegation interfacereferenceindelegation : this ) interfacereferenceset.add( interfacereferenceindelegation.R4013_handles_delegation_for_InterfaceReference() );
        return interfacereferenceset;
    }
    @Override
    public DelegationSet R4013_may_delegate_through_Delegation() throws XtumlException {
        DelegationSet delegationset = new DelegationSetImpl();
        for ( InterfaceReferenceInDelegation interfacereferenceindelegation : this ) delegationset.add( interfacereferenceindelegation.R4013_may_delegate_through_Delegation() );
        return delegationset;
    }


    @Override
    public InterfaceReferenceInDelegation nullElement() {
        return InterfaceReferenceInDelegationImpl.EMPTY_INTERFACEREFERENCEINDELEGATION;
    }

    @Override
    public InterfaceReferenceInDelegationSet emptySet() {
      return new InterfaceReferenceInDelegationSetImpl();
    }

    @Override
    public InterfaceReferenceInDelegationSet emptySet(Comparator<? super InterfaceReferenceInDelegation> comp) {
      return new InterfaceReferenceInDelegationSetImpl(comp);
    }

    @Override
    public InterfaceReferenceInDelegationSet value() {
        return this;
    }

    @Override
    public List<InterfaceReferenceInDelegation> elements() {
        return Arrays.asList(toArray(new InterfaceReferenceInDelegation[0]));
    }

}
